# PureBox

Originally written for [PureMPV](https://github.com/4ndrs/PureMPV), with this utility it is possible to get the relative x, y, height, width coordinates of a drawn rectangle inside an X11 application given its PID. It uses the [Python X library](https://github.com/python-xlib/python-xlib) to communicate with the X server.
